@@ -1,5 +1,9 @@
 #!/bin/sh
 
+if [ "$TERM" = unknown ] || [ -z "$TERM" ]; then
+  export TERM=xterm
+fi
+
 LOCATION="/usr/share/liquidprompt/liquidprompt"
 
 # As if we were in an interactive shell
